--[[

   Noise Function test

--]]




local noise 	= love.math.noise


local SIZE 				= 512

local dots				= {}		-- build the noise dots here

local V_adj				= 0.1		-- arrow keys adjust the tl corner position in 2D noise space
local H_adj				= 0.1

local V_start			= 1001		-- starting position in noise space
local H_start			= 1001

local V_span 			= 1				--  this is the number span of image
local H_span 			= 1

local V_inc				= V_span/SIZE
local H_inc				= H_span/SIZE

local X_pos				= 44			-- indent the active draw space
local Y_pos				= 44


function love.load()

  love.graphics.setBackgroundColor(50, 50, 50)
	love.graphics.setPointSize(1)
	
	
	for i=1, SIZE*SIZE do 											-- points is a table of tables {x_init, y_init, r, g, b}
		dots[i] = {X_pos,Y_pos,128,128,128} 			-- create once and reuse
	end
	
end

function love.keypressed(k)
	
		if k == 'escape' then
      love.event.quit()
		elseif k == 'up' then
			V_start = V_start + V_adj
		elseif k == 'down' then
			V_start = V_start - V_adj
		elseif k == 'left' then
			H_start = H_start + H_adj
		elseif k == 'right' then
			H_start = H_start - H_adj
   end
end


function love.update(dt)
	
	local rgb, index													-- start drawing at beginning of buffer
	for y = 1,SIZE do
		for x = 1,SIZE do
			index = (y-1)*SIZE + x
			rgb = noise( (x*H_inc + H_start), (y*V_inc + V_start) ) * 140   			-- greyscale value in noise space
					+ noise( 2.7*(x*H_inc + H_start), 2.7*(y*V_inc + V_start) ) * 54	-- add some higher order "harmonics"
					+ noise( 3.7*(x*H_inc + H_start), 3.7*(y*V_inc + V_start) ) * 10
					+ noise( 6.7*(x*H_inc + H_start), 5.7*(y*V_inc + V_start) ) * 20  -- the harmonics can be variant in x,y !!
			
			dots[index][1] = X_pos + x
			dots[index][2] = Y_pos + y
			dots[index][3] = rgb
			dots[index][4] = rgb
			dots[index][5] = rgb
		end
	end
	
	end

function love.draw()
	
	love.graphics.setColor(255,255,255,255)				-- white 
	love.graphics.points(dots)										-- throw thousands of points at the GPU each frame (what else has it got to do?)
	
end

